@@ -487,8 +487,3 @@ def name_from_auri(auri: tuple):
 
 update = deep_set
 get = deep_get
-
-
-def get_ts(raw=True):
-    t = datetime.datetime.now()
-    return t if raw else t.isoformat() + "Z"
